@@ -12,18 +12,16 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * License along with this library. If not, see <http://www.gnu.org/licenses/>.
  */
 
+#ifndef __GTK_IM_CONTEXT_SIMPLE_H__
+#define __GTK_IM_CONTEXT_SIMPLE_H__
+
 #if !defined (__GTK_H_INSIDE__) && !defined (GTK_COMPILATION)
 #error "Only <gtk/gtk.h> can be included directly."
 #endif
 
-#ifndef __GTK_IM_CONTEXT_SIMPLE_H__
-#define __GTK_IM_CONTEXT_SIMPLE_H__
-
 #include <gtk/gtkimcontext.h>
 
 
@@ -61,13 +59,19 @@ struct _GtkIMContextSimpleClass
   GtkIMContextClass parent_class;
 };
 
+GDK_AVAILABLE_IN_ALL
 GType         gtk_im_context_simple_get_type  (void) G_GNUC_CONST;
+GDK_AVAILABLE_IN_ALL
 GtkIMContext *gtk_im_context_simple_new       (void);
 
+GDK_AVAILABLE_IN_ALL
 void          gtk_im_context_simple_add_table (GtkIMContextSimple *context_simple,
 					       guint16            *data,
 					       gint                max_seq_len,
 					       gint                n_seqs);
+GDK_AVAILABLE_IN_3_20
+void          gtk_im_context_simple_add_compose_file (GtkIMContextSimple *context_simple,
+                                                      const gchar        *compose_file);
 
 
 G_END_DECLS
